@@ -8,7 +8,8 @@ HEADERS = {
 }
 
 graph = synapse_graph.SynapseGraph(MATRIX_HOMESERVER_DOMAIN, HEADERS, MATRIX_HOMESERVER_DOMAIN, hide_usernames=False)
-graph.calculate_edges(u2u_relation=True)
+json = graph.json
+html = graph.html
 graph.show()
 
-# print(graph.get_html())
+
