@@ -58,7 +58,7 @@ class SynapseGraph:
 
     @property
     def json(self) -> str:
-        return self.graph.to_json()
+        return self.graph.to_json(max_depth=2048)
 
     def show(self, file_name: str = 'nx') -> None:
         """Render and open graph to html"""
